======
DIISCO
======


.. image:: https://img.shields.io/pypi/v/diisco.svg
        :target: https://pypi.python.org/pypi/diisco

A probabilistic programming method to characterize dynamic cellular interactions in longitudinal scRNA-seq data.

Bioarxiv pre-print: https://www.biorxiv.org/content/10.1101/2023.11.14.566956v1

* Free software: MIT license



